@@ -5,6 +5,5 @@ function(begIt)
     if(!is.numeric(begIt))
         stop("begIt ", "must be numeric")
     begIt <- as.integer(begIt)
-    command <- paste("SamplesEmbed.beg :=", begIt)
-    invisible(.C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs"))
+    options("BRugsSamplesBeg" = begIt)
 }
